/*
    This file is part of KOrganizer.
    Copyright (c) 2002 Jan-Pascal van Best <janpascal@vanbest.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/
#ifndef EXCHANGEDIALOG_H
#define EXCHANGEDIALOG_H

#include <kdialogbase.h>
#include <kdatewidget.h>

class TQComboBox;

class ExchangeDialog : public KDialogBase
{
    TQ_OBJECT
  
  public:
    ExchangeDialog( const TQDate &start, const TQDate &end, TQWidget *parent=0);
    virtual ~ExchangeDialog();

  protected slots:
    void slotOk();

  private:
  public:
    KDateWidget *m_start;
    KDateWidget *m_end;
};

#endif
